#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Constants;
use Vhffs::Mailings;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $servername = $cgi->param("name");
my $template;
my $subtemplate;
my $templatesdir = $vhffs->get_config->get_templatedir;

if( $user->is_admin != 1 )
{
	
	$template = new HTML::Template( filename => $templatesdir."/panel/misc/simplemsg.tmpl" );
	my $message = gettext( "You are not allowed to see it");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatesdir."/panel/admin/misc/broadcast_list.tmpl" );
	$template->param( TITLE => gettext("All mailings sent to hosted"));
	my $mailings = Vhffs::Mailings::getall( $vhffs );
	my $result;
	my $body;
	$result = "";
	foreach ( reverse sort keys %{$mailings} )
	{
		$subtemplate = new HTML::Template( filename => $templatesdir."/panel/admin/misc/broadcast_part.tmpl" );
		$body = $mailings->{$_}{'message'};
		( $body  ) = ( $body =~ /^(.{0,200}).*/ );
		$subtemplate->param( ID => $_ );
		$subtemplate->param( DATE => $mailings->{$_}{'date'} );
		$subtemplate->param( DELETE => gettext("Delete this mailing") );
		$subtemplate->param( VIEW => gettext("View this mailing") );
		$subtemplate->param( SUBJECT => $mailings->{$_}{'subject'} );
		$subtemplate->param( BODY => $body ."..." );

		if( $mailings->{$_}{'state'} == 3 )
		{
			$subtemplate->param( STATE => gettext("Awaiting sending") );
		}
		elsif( $mailings->{$_}{'state'} == 6 )
		{
			$subtemplate->param( STATE => gettext("Send") );
		}
		else
		{
			$subtemplate->param( STATE => gettext("Unknown status") );
		}

		$result .= $subtemplate->output;
	}
	$template->param( MAILINGS => $result );

}

$panel->build( $template );
$panel->display;

