#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use DateTime;
use DateTime::Locale;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::Main;
use Vhffs::ObjectFactory;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Tag::Request;
   
my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;
my $templatedir = $panel->{'templatedir'};

$panel->check_modo;

my $template = new Vhffs::Panel::Template( filename => $templatedir.'/panel/admin/tag/request/list.tmpl', die_on_bad_params => 0 );
# HTML::Template is wonderfull, I love to loop three
# times over the same array.
my $user = $panel->{user};
my $loc = DateTime::Locale->load($user->get_lang);

my $requests = Vhffs::Tag::Request::get_all($panel->{vhffs});
foreach my $r (@$requests) {
	if(defined $r->get_requester) {
		$r->{user} = $r->get_requester->get_username ;
	} else {
		$r->{user} = gettext('DELETED');
	}

	if(defined $r->get_tagged) {
		$r->{object} = $r->get_tagged->get_label;
	} else {
		$r->{object} = gettext('DELETED');
	}
	my $dt = DateTime->from_epoch( epoch => $r->{created}, locale => $user->get_lang);
	$r->{created} = $dt->strftime($loc->medium_date_format().' '.$loc->long_time_format());
}
$template->param('REQUESTS' => $requests);

$panel->build($template);
$panel->display;
