#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Group;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $message;
my $owner = $cgi->param("PROJECT_OWNER");

my $repo = $cgi->param( "name" );
my $sure = $cgi->param( "DELETE" );

my $bazaar = Vhffs::Services::Bazaar::get_by_reponame( $vhffs , $repo );

my $templatedir = $vhffs->get_config->get_templatedir;

if( ( ! defined $repo ) || ( ! defined $sure ) )
{
    $message = gettext("CGI Error !");
}
elsif( ! defined $bazaar )
{
	$message = gettext( "Cannot retrieve informations about this repository" );
}
elsif( !$user->can_delete( $bazaar ) )
{
	$message = gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' );
}
elsif( $bazaar->get_status != Vhffs::Constants::ACTIVATED )
{
    $message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
}
elsif( $sure == 0 )
{
	$message = gettext( "This bazaar repository will NOT be deleted" );
}
else
{
	$bazaar->set_status( Vhffs::Constants::TO_DELETE );

	# Commit all the changes for the current user
	if( $bazaar->commit < 0 )
	{
	        $message = gettext("An error occured while deleting the bazaar repository");
	}  
	else  
	{
        $message = gettext("This repository will be deleted");
	}
}

my $template = new HTML::Template( filename => $templatedir."/panel/misc/simplemsg.tmpl" );
$template->param( MESSAGE => $message );

$panel->build( $template );
$panel->display;
