#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::Panel::Main;
use Vhffs::Panel::User;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $cgi = $panel->{cgi};
my $vhffs = $panel->{vhffs};
my $user = $panel->{user};
my $templatedir = $panel->{templatedir};

$panel->set_title( gettext('My Projects') );
my $template = new HTML::Template( filename => $templatedir.'/panel/group/index.tmpl', global_vars => 1);

my $groups = Vhffs::Panel::User::get_groups($user, $Vhffs::Panel::User::RELATION_OWNER);
$template->param( OWNED_PROJECTS => $groups );
$groups = Vhffs::Panel::User::get_groups($user, $Vhffs::Panel::User::RELATION_CONTRIB);
$template->param( CONTRIBUTED_PROJECTS => $groups );
$template->param( OWNED_PROJECTS_TEXT => gettext('Your projects') );
$template->param( CONTRIBUTED_PROJECTS_TEXT => gettext('Projects you contribute to') );
$template->param( NEW_PROJECT_TEXT => gettext('Create new project') );
$template->param( RESUBMIT_TEXT => gettext('Propose a new description') );
$template->param( DELETE_TEXT => gettext('Delete') );

$panel->build( $template );
$panel->display;
