#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '/usr/share/vhffs/api';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Services::MailUser;
use Vhffs::Functions;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;

my $vhffs = $panel->{'vhffs'};
my $templatedir = $panel->{'templatedir'};
my $cgi = $panel->{'cgi'};
my $username = $cgi->param('username');
my $user = Vhffs::User::get_by_username( $vhffs, $username );
my $template;

if ( defined $user && $user->{'state'} == Vhffs::Constants::ACTIVATED )
{
    #create a new password for this user
    my $password = Vhffs::Functions::generate_random_password;
    $user->set_password( $password );
    $user->commit;
    my $mu = init Vhffs::Services::MailUser( $vhffs , $user );
    if( defined $mu  &&  $mu->exists_box) {
        $mu->changepassword( $password );
    } 
  
    # Send a mail with plain password inside
    my $subject = sprintf("Password changed on %s", $vhffs->get_config->get_host_name );
    my $content = sprintf("Hello %s %s,\n\nYou asked for a new password, here are your new login information:\nUser: %s\nPassword: %s\n\n%s Administrators\n", $user->get_firstname, $user->get_lastname, $user->get_username, $password , $vhffs->get_config->get_host_name );
    $user->send_mail_user( $subject, $content );
    
    $template = new HTML::Template( filename => $templatedir."/panel/main/lost_ok.tmpl" );
    
    $template->param( TEXT_WAITPASS => sprintf( gettext("Please wait %s, a new password will be sent to you in a few minutes..."), $username )  );
    $template->param( TEXT_LOGIN => gettext("Login") );
}
else
{
    #if user is not know by VHFFS, we return an error
    $template = new HTML::Template( filename => $templatedir."/panel/main/lost_failed.tmpl" );
    
    $template->param( TEXT_FAILED => gettext("Password recovery failed!") );
    $template->param( TEXT_LOGIN => gettext("Login") );
}


$panel->light( $template );
$panel->display;
